python-enhancements

# python-enhancements - Enhanced Python Classes

[![Github version](https://img.shields.io/github/v/release/manfred-kaiser/python-enhancements?label=github&logo=github)](https://github.com/manfred-kaiser/python-enhancements/releases)
[![PyPI version](https://img.shields.io/pypi/v/python-enhancements.svg?logo=pypi&logoColor=FFE873)](https://pypi.org/project/python-enhancements/)
[![Supported Python versions](https://img.shields.io/pypi/pyversions/python-enhancements.svg?logo=python&logoColor=FFE873)](https://pypi.org/project/python-enhancements/)
[![PyPI downloads](https://img.shields.io/pypi/dm/python-enhancements.svg)](https://pypistats.org/packages/python-enhancements)
[![GitHub](https://img.shields.io/github/license/manfred-kaiser/python-enhancements.svg)](LICENSE)

`enhancements` is a python library which extends various python classes.